<?php

namespace App\Http\Controllers;

use App\Models\Lead;
use App\Models\VendorJob;
use Illuminate\Support\Facades\DB;
use Illuminate\Http\Request;
use Exception;

class LeadController extends Controller
{
    public function store(Request $request)
    {

        // Validate input
        $request->validate([
            'name' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'phone' => 'required|string|max:20',
            'location' => 'required|string|max:255',
            'vehicle_name' => 'required|string|max:255',
            'description' => 'required|string',
        ]);

        try{

            DB::beginTransaction(); // Start transaction

        // Store in database
        $lead = Lead::create([
            'name' => $request->name,
            'email' => $request->email,
            'phone' => $request->phone,
            'location' => $request->location,
            'vehicle_name' => $request->vehicle_name,
            'description' => $request->description,
        ]);

        $job = VendorJob::create([
            'lead_id' => $lead->id,
            'status' => 'pending',
            'is_approved' => 0
        ]);

        DB::commit(); // Commit transaction

        // Redirect with success message
        return back()->with('success', 'Your message has been sent successfully!');
    }
    catch(Exception $e)
    {
        DB::rollBack(); // Rollback on error
        return back()->with('error', 'Server error!');
    }
    }
}
