<?php

namespace App\Livewire;

use App\Models\Lead;
use App\Models\VendorJob;
use Livewire\Component;
use Illuminate\Support\Facades\DB;
use Exception;
use Illuminate\Support\Facades\Http;


class AddJob extends Component
{
    public $name, $email, $phone, $location, $vehicle_name, $description, $longitude, $latitude;

    protected $rules = [
        'name' => 'required|string|max:255',
        'email' => 'required|email|max:255',
        'phone' => 'required|string|max:15',
        'location' => 'required|string|max:255',
        'vehicle_name' => 'required|string|max:255',
        'description' => 'nullable|string',
    ];

    public function getCityFromCoordinates($latitude, $longitude)
{
    $apiKey = env('GOOGLE_PLACES_API_KEY'); // Store API key in .env
    $url = "https://maps.googleapis.com/maps/api/geocode/json?latlng={$latitude},{$longitude}&key={$apiKey}";

    $response = Http::get($url);
    $data = $response->json();


    if ($data['status'] == 'OK') {
        foreach ($data['results'][0]['address_components'] as $component) {
            if (in_array('locality', $component['types'])) {
                return $component['long_name']; // Return city name
            }
        }
    }
    
    return null; // Default if city not found
}

    public function save()
    {
        $this->validate();

        try {

            DB::beginTransaction();

            $city = $this->getCityFromCoordinates($this->latitude, $this->longitude);

            $lead = Lead::create([
                'name' => $this->name,
                'email' => $this->email,
                'phone' => $this->phone,
                'location' => $this->location,
                'vehicle_name' => $this->vehicle_name,
                'description' => $this->description,
                'longitude' => $this->longitude,
                'latitude' => $this->latitude,
                'city' => $city
            ]);

            $vendor = VendorJob::create([
                'lead_id' => $lead->id,
                'status' => 'pending',
                'is_approved' => 1
            ]);

            DB::commit();

            session()->flash('success', 'Job created successfully!');
            return redirect()->route('backend.jobs'); // Change as needed
        } catch (Exception $e) {
            DB::rollBack(); // Rollback on error
            return back()->with('error', 'Server error!');
        }
    }

    public function render()
    {
        return view('livewire.add-job');
    }
}
