<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithFileUploads;
use App\Models\User;
use Exception;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Http;

class AddVendor extends Component
{

    use WithFileUploads;

    public $image, $name, $email, $phone, $password, $password_confirmation, $location, $document, $longitude, $latitude, $city;

    public function getCityFromCoordinates($latitude, $longitude)
    {
        $apiKey = env('GOOGLE_PLACES_API_KEY'); // Store API key in .env
        $url = "https://maps.googleapis.com/maps/api/geocode/json?latlng={$latitude},{$longitude}&key={$apiKey}";

        $response = Http::get($url);
        $data = $response->json();

        if ($data['status'] == 'OK') {
            foreach ($data['results'][0]['address_components'] as $component) {
                if (in_array('locality', $component['types'])) {
                    return $component['long_name']; // Return city name
                }
            }
        }

        return null; // Default if city not found
    }

    public function save()
    {
        $validated = $this->validate([
            'image' => 'nullable|mimes:jpg,jpeg,png|max:2048',
            'name' => 'required',
            'email' => 'required|email|unique:users,email',
            'phone' => 'required|numeric',
            'password' => 'required|min:6|same:password_confirmation',
            'password_confirmation' => 'required',
            'location' => 'required',
            'document' => 'nullable|mimes:jpg,jpeg,png,pdf,docx|max:2048',
        ]);

        try {

            $city = $this->getCityFromCoordinates($this->latitude, $this->longitude);

            // Move image to public storage
            if ($this->image) {
                $validated['image'] = $this->image->store('vendor_images', 'public');
            }

            // Move document to public storage
            if ($this->document) {
                $validated['document'] = $this->document->store('documents', 'public');
            }

            $validated['password'] = Hash::make($validated['password']);

            $validated['roles'] = 2;

            $validated['longitude'] = $this->longitude;
            $validated['latitude'] = $this->latitude;
            $validated['city'] = $city;
            $validated['status'] = 1;
            $validated['is_approved'] = 1;

            User::create($validated);

            return redirect()->route('backend.vendors');
        } catch (Exception $e) {
            return redirect()->back()->with('errors', 'Server error!')->withInput();
        }
    }

    public function render()
    {
        return view('livewire.add-vendor');
    }
}
