<?php

namespace App\Livewire;

use App\Models\Lead;
use App\Models\VendorJob;
use Livewire\Component;
use Illuminate\Support\Facades\DB;
use Exception;
use Illuminate\Support\Facades\Http;

class EditJob extends Component
{
    public $job_id, $name, $email, $phone, $location, $vehicle_name, $description, $longitude, $latitude;

    public function mount($id)
    {
        $job = VendorJob::with('lead')->findOrFail($id);

        $this->job_id = $job->id;
        $this->name = $job->lead->name;
        $this->email = $job->lead->email;
        $this->phone = $job->lead->phone;
        $this->location = $job->lead->location;
        $this->vehicle_name = $job->lead->vehicle_name;
        $this->description = $job->lead->description;
        $this->longitude = $job->lead->longitude;
        $this->latitude = $job->lead->latitude;
    }

    protected $rules = [
        'name' => 'required|string|max:255',
        'email' => 'required|email|max:255',
        'phone' => 'required|string|max:15',
        'location' => 'required|string|max:255',
        'vehicle_name' => 'required|string|max:255',
        'description' => 'nullable|string',
    ];

    public function getCityFromCoordinates($latitude, $longitude)
{
    $apiKey = env('GOOGLE_PLACES_API_KEY'); // Store API key in .env
    $url = "https://maps.googleapis.com/maps/api/geocode/json?latlng={$latitude},{$longitude}&key={$apiKey}";

    $response = Http::get($url);
    $data = $response->json();

    dd($data);

    if ($data['status'] == 'OK') {
        foreach ($data['results'][0]['address_components'] as $component) {
            if (in_array('locality', $component['types'])) {
                return $component['long_name']; // Return city name
            }
        }
    }
    
    return null; // Default if city not found
}

    public function update()
    {
        $this->validate();

        try {
            DB::beginTransaction();

            $job = VendorJob::findOrFail($this->job_id);
            $lead = $job->lead;

            $city = $this->getCityFromCoordinates($this->latitude, $this->longitude);
            
            $lead->update([
                'name' => $this->name,
                'email' => $this->email,
                'phone' => $this->phone,
                'location' => $this->location,
                'vehicle_name' => $this->vehicle_name,
                'description' => $this->description,
                'longitude' => $this->longitude,
                'latitude' => $this->latitude,
                'city' => $city
            ]);

            DB::commit();

            session()->flash('success', 'Job updated successfully!');
            return redirect()->route('backend.jobs'); // Change as needed
        } catch (Exception $e) {
            DB::rollBack();
            session()->flash('error', 'Server error! ' . $e->getMessage());
        }
    }

    public function render()
    {
        return view('livewire.edit-job');
    }
}
