<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithPagination;
use App\Models\User;


class ListUsers extends Component
{
    use WithPagination;

    protected $paginationTheme = 'bootstrap';

    public $search = '';

    public function updatingSearch()
    {
        $this->resetPage();
    }

    public function activateUser($id)
    {
        $user = User::findOrFail($id);
        $user->status = 1;
        $user->save();
    }

    public function deactivateUser($id)
    {
        $user = User::findOrFail($id);
        $user->status = 0;
        $user->save();
    }

    public function render()
    {
        $users = User::where('roles', 3)
            ->when($this->search, function ($query) {
                $query->where(function ($q) {
                    $q->where('name', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->orWhere('phone', 'like', '%' . $this->search . '%')
                        ->orWhere('city', 'like', '%' . $this->search . '%');
                });
            })
            ->paginate(25);

        return view('livewire.list-users', ['users' => $users]);
    }
}
