<?php

namespace App\Livewire;

use Livewire\Component;
use Livewire\WithPagination;
use App\Models\User;
use App\Models\VendorJob;
use Illuminate\Support\Facades\Storage;

class ListVendors extends Component
{
    use WithPagination;

    protected $paginationTheme = 'bootstrap';

    public $search = '';
    public $activeTab = 'requested'; // Default tab
  
    public function updatingSearch()
    {
        $this->resetPage();
    }

    public function setTab($tab)
    {
        $this->activeTab = $tab;
        $this->resetPage();
    }

    public function deleteVendor($vendorId)
    {
        $vendor = User::findOrFail($vendorId);

        if ($vendor->image) {
            Storage::disk('public')->delete($vendor->image);
        }

        if ($vendor->document) {
            Storage::disk('public')->delete($vendor->document);
        }

        $vendor->delete();
        session()->flash('success', 'Vendor deleted successfully!');
    }

    public function activateVendor($id)
    {
        $vendor = User::findOrFail($id);
        $vendor->status = 1;
        $vendor->save();
    }

    public function deactivateVendor($id)
    {
        $vendor = User::findOrFail($id);
        $vendor->status = 0;
        $vendor->save();
    }

    public function approveVendor($id)
    {
        $vendor = User::findOrFail($id);
        $vendor->is_approved = 1;
        $vendor->save();
    }

    public function render()
    {
        $vendors = User::where('roles', 2)
            ->when($this->activeTab === 'requested', function ($query) {
                return $query->where('is_approved', 0);
            })
            ->when($this->activeTab === 'approved', function ($query) {
                return $query->where('is_approved', 1);
            })
            ->when($this->search, function ($query) {
                $query->where(function ($q) {
                    $q->where('name', 'like', '%' . $this->search . '%')
                        ->orWhere('email', 'like', '%' . $this->search . '%')
                        ->orWhere('phone', 'like', '%' . $this->search . '%')
                        ->orWhere('city', 'like', '%' . $this->search . '%');
                });
            })
            ->paginate(25);

        return view('livewire.list-vendors', ['vendors' => $vendors]);
    }
}
