<div>
  <section class="content-header">
    <div class="container-fluid">
      <div class="row mb-2">
        <div class="col-sm-6">
          <h1>Jobs</h1>
        </div>
        <div class="col-sm-6">
          <ol class="breadcrumb float-sm-right">
            <li class="breadcrumb-item"><a href="#">Home</a></li>
            <li class="breadcrumb-item active">Jobs</li>
          </ol>
        </div>
      </div>
    </div><!-- /.container-fluid -->
  </section>

  <section class="content">
    <div class="container-fluid">
      <div class="row">
        <div class="col-12">
          <div class="card">
            <div class="card-header">
              <div class="row">
                <div class="col">
                  <h3 class="card-title">Jobs List</h3>
                </div>
                <div class="col">
                  <a href="{{ route('backend.add.job') }}" class="btn btn-primary float-end" wire:navigate>+ Add</a>
                </div>
              </div>
            </div>

            <!-- Tabs -->
            <ul class="nav nav-tabs mt-3">
              <li class="nav-item">
                <a class="nav-link {{ $tab === 'requested' ? 'active' : '' }}" wire:click="setTab('requested')" href="#">Requested</a>
              </li>
              <li class="nav-item">
                <a class="nav-link {{ $tab === 'pending' ? 'active' : '' }}" wire:click="setTab('pending')" href="#">Pending</a>
              </li>
              <li class="nav-item">
                <a class="nav-link {{ $tab === 'in_progress' ? 'active' : '' }}" wire:click="setTab('in_progress')" href="#">In Progress</a>
              </li>
              <li class="nav-item">
                <a class="nav-link {{ $tab === 'completed' ? 'active' : '' }}" wire:click="setTab('completed')" href="#">Completed</a>
              </li>
            </ul>

            <div class="card-body">
              <div class="card-tools d-flex align-items-center mb-2">
                <label class="mr-2">From</label>
                <input type="date" class="form-control form-control-sm mr-2 w-25" wire:model.live="startDate">
                <label class="mr-2">To</label>
                <input type="date" class="form-control form-control-sm mr-2 w-25" wire:model.live="endDate">

                <div class="input-group input-group-sm w-25">
                  <input type="text" class="form-control form-control-sm" placeholder="Search" wire:model.live.debounce.200ms="search">
                </div>
              </div>


              <!-- Table -->
              <div class="table-responsive">
                <table class="table table-hover text-nowrap">
                  <thead>
                    <tr>
                      <th>ID</th>
                      <th>Name</th>
                      <th>Email</th>
                      <th>Phone</th>
                      <th>Location</th>
                      <th>Vehicle Name</th>
                      <th>Status</th>
                      <th>Actions</th>
                    </tr>
                  </thead>
                  <tbody>
                    @forelse($jobs as $job)
                    <tr>
                      <td class="border p-2">{{ $job->id }}</td>
                      <td class="border p-2">{{ $job->lead->name ?? 'N/A' }}</td>
                      <td class="border p-2">{{ $job->lead->email ?? 'N/A' }}</td>
                      <td class="border p-2">{{ $job->lead->phone ?? 'N/A' }}</td>
                      <td class="border p-2">{{ $job->lead->city ?? 'N/A' }}</td>
                      <td class="border p-2">{{ $job->lead->vehicle_name ?? 'N/A' }}</td>
                      <td class="border p-2">{{ ucfirst($job->status) }}</td>
                      <td>
                        <a class="btn btn-link text-dark" href="{{ route('backend.edit.job', $job->id) }}"><i class="fas fa-edit"></i></a>
                        <button class="btn btn-link text-dark" wire:click="openAssignModal({{ $job->id }})" data-bs-toggle="modal" data-bs-target="#assignVendorModal"><i class="fas fa-user-plus"></i></button>
                        <button class="btn btn-link text-dark" wire:click=""><i class="fas fa-trash"></i></button>
                      </td>
                    </tr>
                    @empty
                    <tr>
                      <td colspan="8" class="border p-2 text-center">No jobs found.</td>
                    </tr>
                    @endforelse
                  </tbody>
                </table>
              </div>

              <!-- Pagination -->
              <div class="p-2 mt-2">
                {{ $jobs->links() }}
              </div>

            </div>
          </div>
        </div>

        <div class="modal fade" id="assignVendorModal" wire:ignore.self>
          <div class="modal-dialog modal-lg">
            <div class="modal-content">
              <div class="modal-header">
                <h4 class="modal-title">Assign Vendor</h4>
                <button type="button" class="close" data-bs-dismiss="modal" aria-label="Close">
                  <span aria-hidden="true">&times;</span>
                </button>
              </div>
              <div class="modal-body">

              <p>Assigned to: {{ $jobAssignedTo }}</p>

              @if(empty($jobAssignedTo))
                <h6 class="mt-3">Approved Vendors List</h6>
                <table class="table table-bordered">
                  <thead>
                    <tr>
                      <th>ID</th>
                      <th>Name</th>
                      <th>Email</th>
                      <th>City</th>
                      <th>Actions</th>
                    </tr>
                  </thead>
                  <tbody>
                    @forelse($vendorsList as $vendor)

                    <tr>
                      <td>{{ $vendor->id }}</td>
                      <td>{{ $vendor->name }}</td>
                      <td>{{ $vendor->email }}</td>
                      <td>{{ $vendor->city ?? 'Not Assigned' }}</td>
                      <td>
                        @if($vendor->id != $assignedVendorId)
                        <button class="btn btn-sm btn-primary" wire:click="assignVendorToJob({{ $vendor->id }})" >Assign</button>
                        @else
                          Assigned
                        @endif
                      </td>
                    </tr>
                    @empty
                    <tr>
                      <td colspan="5" class="text-center">No approved vendors available.</td>
                    </tr>
                    @endforelse
                  </tbody>
                </table>
                @endif
              </div>
              <div class="modal-footer justify-content-between">
                <button type="button" class="btn btn-default" data-bs-dismiss="modal">Close</button>
              </div>
            </div>
            <!-- /.modal-content -->
          </div>
          <!-- /.modal-dialog -->
        </div>

      </div>
  </section>
  <script>
     document.addEventListener('livewire:init', () => {
       Livewire.on('closeModal', (event) => {
        let modal = bootstrap.Modal.getInstance(document.getElementById('assignVendorModal'));
        if (modal) {
            modal.hide();
        }
       });
    });
  </script>
</div>