<?php

use App\Http\Controllers\AuthController;
use App\Http\Controllers\LeadController;
use App\Livewire\AddJob;
use App\Livewire\AddVendor;
use App\Livewire\Dashboard;
use App\Livewire\EditJob;
use App\Livewire\EditVendor;
use App\Livewire\ListJobs;
use App\Livewire\ListVendors;
use App\Livewire\ListUsers;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\Facades\Mail;

// Website Routes
Route::get('/', function () {
    return view('frontend.index');
})->name('frontend.index');
Route::get('login', [AuthController::class, 'websiteLogin'])->name('frontend.login');
Route::post('login', [AuthController::class, 'websiteLogin'])->name('frontend.post.login');
Route::get('register', [AuthController::class, 'websiteRegister'])->name('frontend.register');
Route::post('register', [AuthController::class, 'websiteRegister'])->name('frontend.post.register');
Route::post('contact', [LeadController::class, 'store'])->name('frontend.post.contact');
Route::get('logout', [AuthController::class, 'websiteLogout'])->name('frontend.logout');
Route::get('become-vendor', [AuthController::class, 'vendorRegister'])->name('frontend.vendor.register');
Route::post('become-vendor', [AuthController::class, 'vendorRegister'])->name('frontend.post.vendor.register');
Route::get('forgot-password', [AuthController::class, 'showForgotPasswordForm'])->name('password.request');
Route::post('forgot-password', [AuthController::class, 'sendResetLink'])->name('password.email');
Route::get('reset-password/{token}', [AuthController::class, 'showResetPasswordForm'])->name('password.reset');
Route::post('reset-password', [AuthController::class, 'resetPassword'])->name('password.update');

// Admin Panel Routes
Route::prefix('admin')->group(function () {
    Route::get('login', [AuthController::class, 'login'])->name('backend.login');
    Route::post('login', [AuthController::class, 'login'])->name('backend.post.login');
});

Route::prefix('admin')->middleware(['role:1'])->group(function () {
    Route::get('dashboard', Dashboard::class)->name('backend.dashboard');
    Route::get('logout', [AuthController::class, 'logout'])->name('backend.logout');
    Route::get('jobs', ListJobs::class)->name('backend.jobs');
    Route::get('vendors', ListVendors::class)->name('backend.vendors');
    Route::get('add-vendor', AddVendor::class)->name('backend.add.vendor');
    Route::get('edit-vendor/{id}', EditVendor::class)->name('backend.edit.vendor');
    Route::get('add-job', AddJob::class)->name('backend.add.job');
    Route::get('edit-job/{id}', EditJob::class)->name('backend.edit.job');
    Route::get('users', ListUsers::class)->name('backend.users');
});
